SystemStatus plugin for Juham™
==============================

Description
-----------

System status and diagnosis plugin to Juham™ home automation. When installed acquires and publishes
the following data:

* CPU load
* Available memory
* Available disk space
* Number of active threads

  
.. image:: _static/images/systemstatus.png
   :alt: Built-in status and diagnosis system for JuhaM™ home automation.
   :width: 640px
   :align: center  


Getting Started
---------------

### Installation

1. Install

   .. code-block:: bash

      pip install juham-systemstatus


2. Configure

Works right out of the box. To adjust update interval and other attributes
edit `SystemStatus.json` configuration file.

